.. _tutorials-django:

====================================
Run a Django site with Pulsar
====================================

The code for this example is located in the :mod:`examples.djangoapp.manage`
module.

.. automodule:: examples.djangoapp.manage